cls
showinc on
#
#
#
#
#
#
# Welcome to SIGLAB.  This self-running demonstration was
# written entirely in the SIGLAB language and is illustrative
# of the types of user-defined programs and functions you
# can write.
#
#
#
showinc off
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
cls
showinc on
#
#
#
#
#
#
# We will demonstrate the design and analysis of an AM communication
# system for the transmission and reception of an electrocardiogram
# (ECG) signal.  The ECG signal is sampled at 500 Hz and is con-
# taminated with 60 Hz noise.  We will be using the IIR notch filter 
# and the FIR lowpass filter which were designed in MONARCH.
#
#
#
#
#
showinc off
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
showinc on
# READ IN THE DATA FILE CONTAINING THE ECG SIGNAL
x = rf("ecg.dat")
# READ IN THE Tx/Rx FIR LOWPASS FILTER
h1 = rf("ecgfir.imp")
# READ IN THE ARCHITECTURE FILE FOR THE IIR NOTCH FILTER
h2 = rarc("ecgiir.arc", 1)
# CREATE AN IMPULSE RESPONSE FOR THE Tx/Rx FILTER
h1imp = h1 & zeros(256 - len(h1))
# CREATE AN IMPULSE RESPONSE FOR THE IIR NOTCH FILTER
h2imp = filt(h2, impulse(256))
showinc off
# SET UP OPTIONAL X-AXIS FOR NORMALIZED FREQUENCY RESPONSE
s1=rmp(128,.5/128,128)
s1[127]=.5 
s2=-.5+rmp(256,1/256,256)
s2[255]=.5 
# SET UP OPTIONAL ATTRIBUTES FOR THE FIRST GRAPH
gattrib(YELLOW, SOLID, 5, 0)
# LABEL THE FIRST GRAPH
glabel("Noisy ECG Signal", TITLE, 0)
# SET UP OPTIONAL ATTRIBUTES FOR THE SECOND GRAPH
gattrib(LTGREEN, BAR, 5, 1)
# LABEL THE SECOND GRAPH
glabel("Receive Filter Impulse Response", TITLE, 1)
# SET UP OPTIONAL ATTRIBUTES FOR THE THIRD GRAPH
gattrib(LTBLUE, BAR, 5, 2)
# LABEL THE THIRD GRAPH
glabel("Notch Filter Impulse Response", TITLE, 2)
echo "# GRAPH THE DATA\n"
echo "graph(x, h1, h2imp)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
graph(x, h1, h2imp)
showinc on
# CALCULATE THE POSITIVE FFT OF THE SIGNAL 
xf = mag(pfft(x))
# CALCULATE THE POSITIVE FFT OF THE Tx/Rx FILTER IMPULSE RESPONSE
h1impf = mag(pfft(h1imp))
# CALCULATE THE ENTIRE FFT OF THE Tx/Rx FILTER IMPULSE RESPONSE
h1impnf = mag(fft(h1imp))
# CALCULATE THE ENTIRE FFT OF THE IIR NOTCH FILTER 
h2impf = mag(fft(h2imp))
showinc off
# CHANGE OPTIONAL ATTRIBUTES FOR FIRST GRAPH
gattrib(YELLOW, BAR, 5, 0)
glabel("FFT of Noisy ECG Signal", TITLE, 0)
glabel("Normalized frequency",XAXIS,0)
# CHANGE LABEL OF SECOND GRAPH
glabel("Normalized frequency",XAXIS,1)
glabel("FFT of Receive Filter Impulse Response", TITLE, 1)
# CHANGE OPTIONAL ATTRIBUTES FOR THE THIRD GRAPH
gattrib(LTBLUE, SOLID, 5, 2)
# CHANGE LABEL OF THIRD GRAPH
glabel("Normalized frequency",XAXIS,2)
glabel("FFT of Notch Filter Impulse Response", TITLE, 2)
echo "# GRAPH THE DATA\n"
echo "graph(x, h1impf, h2impf)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
graph(<s1,xf>, <s1,h1impf>, <s2,h2impf>)
showinc on
# FILTER THE ECG SIGNAL TO REMOVE THE NOISE
y1 = filt(h2, x)
# CALCULATE THE POSITIVE FFT OF THE FILTERED ECG SIGNAL
y1f = mag(pfft(y1))
showinc off
# CHANGE THE OPTIONAL ARRTIBUTES FOR THE FIRST GRAPH
gattrib(YELLOW, SOLID, 5, 0)
# CHANGE LABEL OF FIRST GRAPH
glabel("Sample",XAXIS,0)
glabel("Noisy ECG Signal", TITLE, 0)
# CHANGE LABEL OF SECOND GRAPH
glabel("Normalized frequency",XAXIS,1)
glabel("FFT of Noisy ECG Signal", TITLE, 1)
# CHANGE OPTIONAL ATTRIBUTES FOR THE THIRD GRAPH
gattrib(LTBLUE, SOLID, 5, 2)
# CHANGE LABEL OF THIRD GRAPH
glabel("Sample",XAXIS,2)
glabel("Filtered ECG Signal", TITLE, 2)
# CHANGE OPTIONAL ATTRIBUTES OF FOURTH GRAPH
gattrib(LTCYAN, BAR, 5, 3)
# LABEL FOURTH GRAPH
glabel("Normalized frequency",XAXIS,3)
glabel("FFT of Filtered ECG Signal", TITLE, 3)
echo "# GRAPH DATA\n"
echo "graph(x, xf, y1, y1f)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
graph(x, <s1,xf>, y1, <s1,y1f>)
cls
showinc on
# CREATE A CARRIER AT 1/4 THE NYQUIST FREQUENCY
c = mksin(1, 1/4, 0, 256)
# BANDLIMIT THE ECG SIGNAL WITH Tx/Rx FILTER (CONVOLUTION)
y1a = y1 $ h1
showinc off
# ADJUST THE LENGTH OF THE SIGNAL
y1a = y1a[(len(h1)-1)/2:len(y1a)-(len(h1)+1)/2]
showinc on
# CALCULATE THE POSITIVE FFT OF THE Tx SIGNAL
y1af = mag(pfft(y1a))
# MODULATE THE Tx SIGNAL
tx = c .* y1a
# DEMODULATE THE Tx SIGNAL
rx = c .* tx
# CALCULATE THE FFT OF THE CARRIER
cf = mag(fft(c))
# CALCULATE THE FFT OF THE Tx SIGNAL
txf = mag(fft(tx))
# CALCULATE THE FFT OF THE Rx SIGNAL
rxf = mag(fft(rx))
showinc off
# CHANGE LABEL OF FIRST GRAPH
glabel("Carrier", TITLE, 0)
glabel("Sample",XAXIS,0)
# CHANGE LABEL OF SECOND GRAPH
glabel("FFT of the Carrier", TITLE, 1)
glabel("Normalized frequency",XAXIS,1)
# CHANGE OPTIONAL ATTRIBUTES OF SECOND GRAPH
gattrib(LTGREEN,BAR,5,1)
# CHANGE OPTIONAL ATTRIBUTES OF THIRD GRAPH
gattrib(LTBLUE, BAR, 5, 2)
# CHANGE LABEL OF THIRD GRAPH
glabel("FFT of the Transmitted Signal", TITLE, 2)
glabel("Normalized frequency",XAXIS,2)
# CHANGE OPTIONAL ATTRIBUTES OF FOURTH GRAPH
gattrib(LTCYAN, BAR, 5, 3)
# CHANGE LABEL OF FOURTH GRAPH
glabel("FFT of the Demodulated Signal", TITLE, 3)
glabel("Normalized frequency",XAXIS,3)
echo "# GRAPH DATA\n"
echo "graph(c, cf, txf, rxf)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
graph(c, <s2,cf>, <s2,txf>, <s2,rxf>)
# CHANGE ATTRIBUTES OF FIRST GRAPH
gattrib(YELLOW, BAR, 5, 0)
# CHANGE LABEL OF FIRST GRAPH
glabel("FFT of the Received Signal", TITLE, 0)
glabel("Normalized frequency",XAXIS,0)
# CHANGE LABEL OF SECOND GRAPH
glabel("FFT of the Receive Filter", TITLE, 1)
glabel("Normalized frequency",XAXIS,1)
echo "# GRAPH FFT OF RECEIVED SIGNAL\n"
echo "# AND FFT of RECEIVER LOWPASS\n"
echo "# FILTER IMPULSE RESPONSE\n"
echo "graph(rxf, h1impnf)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
graph(<s2,rxf>, <s2,h1impnf>)
showinc on
# AMPLIFY AND LOWPASS FILTER Rx SIGNAL (CONVOLUTION)
y2 = 2 .* (h1 $ rx)
showinc off
# ADJUST THE LENGTH
y2a = y2[(len(h1)-1)/2:len(y2)-(len(h1)+1)/2]
showinc on
# CALCULATE THE POSITIVE FFT OF THE FILTERED Rx SIGNAL
y2af = mag(pfft(y2a))
showinc off
# CHANGE OPTIONAL ATTRIBUTES FOR THE FIRST GRAPH
gattrib(YELLOW, SOLID, 5, 0)
# CHANGE LABEL OF THE FIRST GRAPH
glabel("Sample",XAXIS,0)
glabel("Transmitted ECG Signal", TITLE, 0)
# CHANGE LABEL OF SECOND GRAPH
glabel("Normalized frequency",XAXIS,1)
glabel("FFT of Transmitted ECG Signal", TITLE, 1)
# CHANGE LABEL OF THIRD GRAPH
glabel("Sample",XAXIS,2)
glabel("Received ECG Signal", TITLE, 2)
# CHANGE OPTIONAL ATTRIBUTES OF THIRD GRAPH
gattrib(LTBLUE, SOLID, 5, 2)
# CHANGE LABEL OF FOURTH GRAPH
glabel("Normalized frequency",XAXIS,3)
glabel("FFT of Received ECG Signal", TITLE, 3)
echo "# GRAPH DATA\n"
echo "graph(y1a, y1af, y2a, y2af)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
graph(y1a, <s1,y1af>, y2a, <s1,y2af>)
# CHANGE OPTIONAL ATTRIBUTES OF SECOND GRAPH
gattrib(LTGREEN, SOLID, 5, 1)
glabel("Sample",XAXIS,1)
# CHANGE LABEL OF FIRST GRAPH
glabel("Overlay of Xmitted and Rec'd Signals", TITLE, 0)
glabel("Sample",XAXIS,0)
echo "# OVERLAY THE Tx AND Rx SIGNALS\n"
echo "ograph(y1, y2a)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
cls
ograph(y1, y2a)
# CHANGE OPTIONAL ATTRIBUTES OF FIRST GRAPH
gattrib(LTRED, DOTTED, 5, 0)
# CHANGE LABEL OF FIRST GRAPH
glabel("Error Between TX and RX Signal", TITLE, 0)
echo "# GRAPH DIFFERENCE BETWEEN THE TRANS-\n"
echo "# MITTED AND RECEIVED SIGNALS\n"
echo "graph((y1a - y2a)./y1a)\n"
pause "<<<<< PRESS ESC TO CONTINUE >>>>>"
graph((y1a - y2a)./y1a)
delvar
gdefault
cls
showinc on
# THIS CONCLUDES THE SIGLAB DEMO. FOR HELP USING SIGLAB, 
# TYPE F1 FOR A LIST OF COMMANDS AND DOCUMENTATION ON THEIR USE.
# FOR EXAMPLE,
#
#            x=gn(256)+mksin(1,.25,0,256)
#
# CREATES A SINE WAVE OF UNIT AMPLITUDE AT 1/4-TH THE SAMPLING
# FREQUENCY WITH ZERO PHASE AND LENGTH 256 WITH ADDITIVE GAUSSIAN 
# NOISE.  TO EXAMINE THE SIGNAL AND ITS FREQUENCY CONTENT, TYPE
#
#            graph(x, mag(fft(x)))
